@@ -1,15 +1,17 @@
+#' @keywords internal
+"_PACKAGE"
+
 #' Code and Data Accompanying the Eco-Stats Text
 #'
-#' Functions and data supporting the Ecostats text (Warton, forthcoming, Springer), and solutions to 
+#' Functions and data supporting the Ecostats text (Warton 2022), and solutions to 
 #' exercises. Functions include tools for using simulation envelopes in diagnostic plots, and a
-#' function for diagnostic plots of multivariate linear models. Datasets mentioned in the package 
-#' are included here (where not available elsewhere) and vignette solutions to textbook exercises 
-#' will be forthcoming at a later time.
+#' function for diagnostic plots of multivariate linear models. Datasets mentioned in the text
+#' are included here (where not available elsewhere) and vignette solutions to textbook exercises.
 #'
 #' @docType package
-#'
-#'
-#' @rdname ecostats-package
+#' 
+#' @references Warton DI (2022) Eco-Stats - Data Analysis in Ecology, from \emph{t}-tests to multivariate abundances. Springer, ISBN 978-3-030-88442-0
+#' 
 #' @examples
 #' # spaghetti plot of longitudinal data from bird exclusion field experiment:
 #' data(aphids)
@@ -24,3 +26,6 @@
 #' iris.mlm=lm(cbind(Sepal.Length,Sepal.Width,Petal.Length,Petal.Width)~Species,data=iris)
 #' # construct residual vs fits and QQ plot
 #' plot(iris.mlm, which=1:2)
+
+#' @export
+
